==> camel-k-model-v1-6.1.0-sources.jar: io/fabric8/camelk/v1/IntegrationFluentImpl.java <==
package io.fabric8.camelk.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class IntegrationFluentImpl<A extends IntegrationFluent<A>> extends BaseFluent<A> implements IntegrationFluent<A>{
  public IntegrationFluentImpl() {
  }
  public IntegrationFluentImpl(Integration instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private IntegrationSpecBuilder spec;
  private IntegrationStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public IntegrationFluent.MetadataNested<A> withNewMetadata() {
    return new IntegrationFluentImpl.MetadataNestedImpl();
  }
  public IntegrationFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new IntegrationFluentImpl.MetadataNestedImpl(item);
  }
  public IntegrationFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public IntegrationFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public IntegrationFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public IntegrationSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public IntegrationSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(IntegrationSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new IntegrationSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public IntegrationFluent.SpecNested<A> withNewSpec() {
    return new IntegrationFluentImpl.SpecNestedImpl();
  }
  public IntegrationFluent.SpecNested<A> withNewSpecLike(IntegrationSpec item) {
    return new IntegrationFluentImpl.SpecNestedImpl(item);
  }
  public IntegrationFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public IntegrationFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new IntegrationSpecBuilder().build());
  }
  public IntegrationFluent.SpecNested<A> editOrNewSpecLike(IntegrationSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public IntegrationStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public IntegrationStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(IntegrationStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new IntegrationStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public IntegrationFluent.StatusNested<A> withNewStatus() {
    return new IntegrationFluentImpl.StatusNestedImpl();
  }
  public IntegrationFluent.StatusNested<A> withNewStatusLike(IntegrationStatus item) {
    return new IntegrationFluentImpl.StatusNestedImpl(item);
  }
  public IntegrationFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public IntegrationFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new IntegrationStatusBuilder().build());
  }
  public IntegrationFluent.StatusNested<A> editOrNewStatusLike(IntegrationStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    IntegrationFluentImpl that = (IntegrationFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<IntegrationFluent.MetadataNested<N>> implements IntegrationFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) IntegrationFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends IntegrationSpecFluentImpl<IntegrationFluent.SpecNested<N>> implements IntegrationFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(IntegrationSpec item) {
      this.builder = new IntegrationSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new IntegrationSpecBuilder(this);
    }
    IntegrationSpecBuilder builder;
    public N and() {
      return (N) IntegrationFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends IntegrationStatusFluentImpl<IntegrationFluent.StatusNested<N>> implements IntegrationFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(IntegrationStatus item) {
      this.builder = new IntegrationStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new IntegrationStatusBuilder(this);
    }
    IntegrationStatusBuilder builder;
    public N and() {
      return (N) IntegrationFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> camel-k-model-v1-6.7.2-sources.jar: io/fabric8/camelk/v1/IntegrationFluentImpl.java <==
package io.fabric8.camelk.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class IntegrationFluentImpl<A extends IntegrationFluent<A>> extends BaseFluent<A> implements IntegrationFluent<A>{
  public IntegrationFluentImpl() {
  }
  public IntegrationFluentImpl(Integration instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private IntegrationSpecBuilder spec;
  private IntegrationStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public IntegrationFluentImpl.MetadataNested<A> withNewMetadata() {
    return new IntegrationFluentImpl.MetadataNestedImpl();
  }
  public IntegrationFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new IntegrationFluentImpl.MetadataNestedImpl(item);
  }
  public IntegrationFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public IntegrationFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public IntegrationFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public IntegrationSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public IntegrationSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(IntegrationSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new IntegrationSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public IntegrationFluentImpl.SpecNested<A> withNewSpec() {
    return new IntegrationFluentImpl.SpecNestedImpl();
  }
  public IntegrationFluentImpl.SpecNested<A> withNewSpecLike(IntegrationSpec item) {
    return new IntegrationFluentImpl.SpecNestedImpl(item);
  }
  public IntegrationFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public IntegrationFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new IntegrationSpecBuilder().build());
  }
  public IntegrationFluentImpl.SpecNested<A> editOrNewSpecLike(IntegrationSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public IntegrationStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public IntegrationStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(IntegrationStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new IntegrationStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public IntegrationFluentImpl.StatusNested<A> withNewStatus() {
    return new IntegrationFluentImpl.StatusNestedImpl();
  }
  public IntegrationFluentImpl.StatusNested<A> withNewStatusLike(IntegrationStatus item) {
    return new IntegrationFluentImpl.StatusNestedImpl(item);
  }
  public IntegrationFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public IntegrationFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new IntegrationStatusBuilder().build());
  }
  public IntegrationFluentImpl.StatusNested<A> editOrNewStatusLike(IntegrationStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    IntegrationFluentImpl that = (IntegrationFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<IntegrationFluentImpl.MetadataNested<N>> implements IntegrationFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) IntegrationFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends IntegrationSpecFluentImpl<IntegrationFluentImpl.SpecNested<N>> implements IntegrationFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(IntegrationSpec item) {
      this.builder = new IntegrationSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new IntegrationSpecBuilder(this);
    }
    IntegrationSpecBuilder builder;
    public N and() {
      return (N) IntegrationFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends IntegrationStatusFluentImpl<IntegrationFluentImpl.StatusNested<N>> implements IntegrationFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(IntegrationStatus item) {
      this.builder = new IntegrationStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new IntegrationStatusBuilder(this);
    }
    IntegrationStatusBuilder builder;
    public N and() {
      return (N) IntegrationFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
